Nomine
===============================

version number: 0.0.1
author: Nomine

Overview
--------

A complete markov chain name generator

Installation / Usage
--------------------

To install use pip:

    $ pip install nomine


Or clone the repo:

    $ git clone https://github.com/eranimo/nomine.git
    $ python setup.py install
    
Contributing
------------

TBD

Example
-------

TBD